@@ -1,50 +1,17 @@
 """
 	Redid CLI tools entry point.
 """
-from __future__ import print_function
+import sys, os, yaml, argparse, json, mimetypes, urllib
 
-import sys, os, yaml, argparse, requests, base64, json, mimetypes, urllib
+from common import log
+import common
 
-api_endpoint = 'https://api.redid.net'
 verbose = False
 config = None
-
-def log( *args ):
-	""" Do not use "print" to output log/trace/verbose info as it will interfere with the stdout. """
-	print( *args, file = sys.stderr )
-	
-def load_config( path ):
-	if not os.path.exists( path ):
-		return None
-			
-	data = yaml.load( file( path, 'r' ) )
-	if 'access' not in data:
-		data['access'] = {}
-
-	# Environment overrides
-	account = os.environ.get( 'REDID_ACCOUNT', None )
-	user = os.environ.get( 'REDID_USER', None )
-	password = os.environ.get( 'REDID_PASSWORD', None )
-
-	if account != None:
-		data['access']['account'] = account
-	if user != None:
-		data['access']['user'] = user
-	if password != None:
-		data['access']['password'] = password
-
-	if data['access']['account'] == None or \
-		data['access']['user'] == None or \
-		data['access']['password'] == None:
-		log( "Missing access settings in configuration <{}>".format( path ) )
-		return None
-		
-	return data
-
 	
 def cmd_setup( args ):
 	""" Create/Update the configuration file """
-	config = load_config( args.config )
+	config = common.load_config( args )
 	if config == None:
 		config = {}
 	if 'access' not in config:
@@ -227,7 +194,7 @@ def cmd_get_resource_url( args ):
 
 def main():
 	opts = argparse.ArgumentParser()
-	opts.add_argument( "--config", help = "use this configuration file", default="~/.redid.yaml" )
+	common.add_config_args( opts )
 	opts.add_argument( "--verbose", help = "show verbose output", action='store_const', const = True )
 	opts.add_argument( "--save", help = "save the command result to this file instead of displaying",
 		nargs = "?" )
@@ -309,13 +276,12 @@ def main():
 	args = opts.parse_args()
 	global verbose
 	verbose = args.verbose
-	args.config = os.path.expanduser( args.config )
 	
 	if args.command == 'setup':
 		args.func( args )
 	else:
 		global config
-		config = load_config( args.config )
+		config = common.load_config( args )
 		if config == None:
 			log( "Unable to load configuration. Please run 'redid setup' " )
 			sys.exit(1)
@@ -323,40 +289,8 @@ def main():
 			sys.exit(2)
 
 		
-def api_request( method, path, json_data = None, data = None, query_string = None, headers = None ):
-	"""
-		Issue a request to the API server for the account.
-	"""
-	path = "/{}/{}".format( config['access']['account'], path )
-	
-	if headers == None:
-		headers = {}
-	headers['Authorization'] = 'Basic ' + base64.b64encode( "{}:{}".format(
-		config['access']['user'], config['access']['password'] ) )
-		
-	if json_data != None:
-		assert data == None
-		data = json.dumps( json_data )
-		headers['Content-Type'] = 'application/json'
-
-	if verbose:
-		log( '{} {} {}'.format( method, api_endpoint + path, str(query_string) ) )
-	resp = requests.request( method, api_endpoint + path, headers = headers, data = data,
-		params = query_string )
-	
-	jdata = None
-	if resp.headers['Content-Type'] == 'application/json':
-		jdata = resp.json()
-		
-	if resp.status_code != 200:
-		log( "Failed with HTTP status {}".format( resp.status_code ) )
-		if jdata != None:
-			show_data( jdata )
-		return None
-
-	if jdata != None:
-		return jdata
-	return resp.content
+def api_request( *args, **kwargs ):
+	return common.api_request( *args, config = config, verbose = verbose, **kwargs )
 
 	
 def handle_object_response( args, data ):
@@ -376,15 +310,7 @@ def handle_data( args, data, binary = False ):
 	if args.save != None:
 		save_data( data, args.save, binary = binary )
 	else:
-		show_data( data, binary = binary )
-
-		
-def show_data( data, binary = False ):
-	""" Display data on stdout."""
-	if binary:
-		sys.stdout.write( data )
-	else:
-		print( yaml.safe_dump( data, allow_unicode=True, default_flow_style = False ) )
+		common.show_data( data, binary = binary )
 
 	
 def save_data( data, filename, binary = False ):
